run

Function run 

pub fn run()
Run the cellctl CLI. Returns when the command completes or exits the process on error via CtlError::exit. This is the entry point both the standalone cellctl binary and the cellos meta-crate’s cellctl shim call into.